==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkStringArray.java <==
// java wrapper for vtkStringArray object
//

package vtk;
import vtk.*;

public class vtkStringArray extends vtkAbstractArray
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataType_2();
  public int GetDataType()
    { return GetDataType_2(); }

  private native int IsNumeric_3();
  public int IsNumeric()
    { return IsNumeric_3(); }

  private native void Initialize_4();
  public void Initialize()
    { Initialize_4(); }

  private native int GetDataTypeSize_5();
  public int GetDataTypeSize()
    { return GetDataTypeSize_5(); }

  private native void Squeeze_6();
  public void Squeeze()
    { Squeeze_6(); }

  private native int Resize_7(int id0);
  public int Resize(int id0)
    { return Resize_7(id0); }

  private native void SetTuple_8(int id0,int id1,vtkAbstractArray id2);
  public void SetTuple(int id0,int id1,vtkAbstractArray id2)
    { SetTuple_8(id0,id1,id2); }

  private native void InsertTuple_9(int id0,int id1,vtkAbstractArray id2);
  public void InsertTuple(int id0,int id1,vtkAbstractArray id2)
    { InsertTuple_9(id0,id1,id2); }

  private native void InsertTuples_10(vtkIdList id0,vtkIdList id1,vtkAbstractArray id2);
  public void InsertTuples(vtkIdList id0,vtkIdList id1,vtkAbstractArray id2)
    { InsertTuples_10(id0,id1,id2); }

  private native void InsertTuples_11(int id0,int id1,int id2,vtkAbstractArray id3);
  public void InsertTuples(int id0,int id1,int id2,vtkAbstractArray id3)
    { InsertTuples_11(id0,id1,id2,id3); }

  private native int InsertNextTuple_12(int id0,vtkAbstractArray id1);
  public int InsertNextTuple(int id0,vtkAbstractArray id1)
    { return InsertNextTuple_12(id0,id1); }

  private native void InterpolateTuple_13(int id0,int id1,vtkAbstractArray id2,int id3,vtkAbstractArray id4,double id5);
  public void InterpolateTuple(int id0,int id1,vtkAbstractArray id2,int id3,vtkAbstractArray id4,double id5)
    { InterpolateTuple_13(id0,id1,id2,id3,id4,id5); }

  private native void GetTuples_14(vtkIdList id0,vtkAbstractArray id1);
  public void GetTuples(vtkIdList id0,vtkAbstractArray id1)
    { GetTuples_14(id0,id1); }

  private native void GetTuples_15(int id0,int id1,vtkAbstractArray id2);
  public void GetTuples(int id0,int id1,vtkAbstractArray id2)
    { GetTuples_15(id0,id1,id2); }

  private native int Allocate_16(int id0,int id1);
  public int Allocate(int id0,int id1)
    { return Allocate_16(id0,id1); }

  private native String GetValue_17(int id0);
  public String GetValue(int id0)
    { return GetValue_17(id0); }

  private native void SetValue_18(int id0,String id1);
  public void SetValue(int id0,String id1)
    { SetValue_18(id0,id1); }

  private native void SetNumberOfTuples_19(int id0);
  public void SetNumberOfTuples(int id0)
    { SetNumberOfTuples_19(id0); }

  private native void SetNumberOfValues_20(int id0);
  public void SetNumberOfValues(int id0)
    { SetNumberOfValues_20(id0); }

  private native int GetNumberOfValues_21();
  public int GetNumberOfValues()
    { return GetNumberOfValues_21(); }

  private native int GetNumberOfElementComponents_22();
  public int GetNumberOfElementComponents()
    { return GetNumberOfElementComponents_22(); }

  private native int GetElementComponentSize_23();
  public int GetElementComponentSize()
    { return GetElementComponentSize_23(); }

  private native void InsertValue_24(int id0,String id1);
  public void InsertValue(int id0,String id1)
    { InsertValue_24(id0,id1); }

  private native int InsertNextValue_25(String id0);
  public int InsertNextValue(String id0)
    { return InsertNextValue_25(id0); }

  private native void DeepCopy_26(vtkAbstractArray id0);
  public void DeepCopy(vtkAbstractArray id0)
    { DeepCopy_26(id0); }

  private native int GetActualMemorySize_27();
  public int GetActualMemorySize()
    { return GetActualMemorySize_27(); }

  private native long NewIterator_28();
  public vtkArrayIterator NewIterator() {
    long temp = NewIterator_28();

    if (temp == 0) return null;
    return (vtkArrayIterator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetDataSize_29();
  public int GetDataSize()
    { return GetDataSize_29(); }

  private native int LookupValue_30(String id0);
  public int LookupValue(String id0)
    { return LookupValue_30(id0); }

  private native void LookupValue_31(String id0,vtkIdList id1);
  public void LookupValue(String id0,vtkIdList id1)
    { LookupValue_31(id0,id1); }

  private native void DataChanged_32();
  public void DataChanged()
    { DataChanged_32(); }

  private native void DataElementChanged_33(int id0);
  public void DataElementChanged(int id0)
    { DataElementChanged_33(id0); }

  private native void ClearLookup_34();
  public void ClearLookup()
    { ClearLookup_34(); }

  public vtkStringArray() { super(); }

  public vtkStringArray(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-20-armv6h.pkg.tar.xz: vtk/vtkStringArray.java <==
// java wrapper for vtkStringArray object
//

package vtk;
import vtk.*;

public class vtkStringArray extends vtkAbstractArray
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataType_2();
  public int GetDataType()
    { return GetDataType_2(); }

  private native int IsNumeric_3();
  public int IsNumeric()
    { return IsNumeric_3(); }

  private native void Initialize_4();
  public void Initialize()
    { Initialize_4(); }

  private native int GetDataTypeSize_5();
  public int GetDataTypeSize()
    { return GetDataTypeSize_5(); }

  private native void Squeeze_6();
  public void Squeeze()
    { Squeeze_6(); }

  private native int Resize_7(int id0);
  public int Resize(int id0)
    { return Resize_7(id0); }

  private native void SetTuple_8(int id0,int id1,vtkAbstractArray id2);
  public void SetTuple(int id0,int id1,vtkAbstractArray id2)
    { SetTuple_8(id0,id1,id2); }

  private native void InsertTuple_9(int id0,int id1,vtkAbstractArray id2);
  public void InsertTuple(int id0,int id1,vtkAbstractArray id2)
    { InsertTuple_9(id0,id1,id2); }

  private native void InsertTuples_10(vtkIdList id0,vtkIdList id1,vtkAbstractArray id2);
  public void InsertTuples(vtkIdList id0,vtkIdList id1,vtkAbstractArray id2)
    { InsertTuples_10(id0,id1,id2); }

  private native void InsertTuples_11(int id0,int id1,int id2,vtkAbstractArray id3);
  public void InsertTuples(int id0,int id1,int id2,vtkAbstractArray id3)
    { InsertTuples_11(id0,id1,id2,id3); }

  private native int InsertNextTuple_12(int id0,vtkAbstractArray id1);
  public int InsertNextTuple(int id0,vtkAbstractArray id1)
    { return InsertNextTuple_12(id0,id1); }

  private native void InterpolateTuple_13(int id0,int id1,vtkAbstractArray id2,int id3,vtkAbstractArray id4,double id5);
  public void InterpolateTuple(int id0,int id1,vtkAbstractArray id2,int id3,vtkAbstractArray id4,double id5)
    { InterpolateTuple_13(id0,id1,id2,id3,id4,id5); }

  private native void GetTuples_14(vtkIdList id0,vtkAbstractArray id1);
  public void GetTuples(vtkIdList id0,vtkAbstractArray id1)
    { GetTuples_14(id0,id1); }

  private native void GetTuples_15(int id0,int id1,vtkAbstractArray id2);
  public void GetTuples(int id0,int id1,vtkAbstractArray id2)
    { GetTuples_15(id0,id1,id2); }

  private native int Allocate_16(int id0,int id1);
  public int Allocate(int id0,int id1)
    { return Allocate_16(id0,id1); }

  private native String GetValue_17(int id0);
  public String GetValue(int id0)
    { return GetValue_17(id0); }

  private native void SetValue_18(int id0,String id1);
  public void SetValue(int id0,String id1)
    { SetValue_18(id0,id1); }

  private native void SetNumberOfTuples_19(int id0);
  public void SetNumberOfTuples(int id0)
    { SetNumberOfTuples_19(id0); }

  private native void SetNumberOfValues_20(int id0);
  public void SetNumberOfValues(int id0)
    { SetNumberOfValues_20(id0); }

  private native int GetNumberOfValues_21();
  public int GetNumberOfValues()
    { return GetNumberOfValues_21(); }

  private native int GetNumberOfElementComponents_22();
  public int GetNumberOfElementComponents()
    { return GetNumberOfElementComponents_22(); }

  private native int GetElementComponentSize_23();
  public int GetElementComponentSize()
    { return GetElementComponentSize_23(); }

  private native void InsertValue_24(int id0,String id1);
  public void InsertValue(int id0,String id1)
    { InsertValue_24(id0,id1); }

  private native int InsertNextValue_25(String id0);
  public int InsertNextValue(String id0)
    { return InsertNextValue_25(id0); }

  private native void DeepCopy_26(vtkAbstractArray id0);
  public void DeepCopy(vtkAbstractArray id0)
    { DeepCopy_26(id0); }

  private native int GetActualMemorySize_27();
  public int GetActualMemorySize()
    { return GetActualMemorySize_27(); }

  private native long NewIterator_28();
  public vtkArrayIterator NewIterator() {
    long temp = NewIterator_28();

    if (temp == 0) return null;
    return (vtkArrayIterator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetDataSize_29();
  public int GetDataSize()
    { return GetDataSize_29(); }

  private native int LookupValue_30(String id0);
  public int LookupValue(String id0)
    { return LookupValue_30(id0); }

  private native void LookupValue_31(String id0,vtkIdList id1);
  public void LookupValue(String id0,vtkIdList id1)
    { LookupValue_31(id0,id1); }

  private native void DataChanged_32();
  public void DataChanged()
    { DataChanged_32(); }

  private native void DataElementChanged_33(int id0);
  public void DataElementChanged(int id0)
    { DataElementChanged_33(id0); }

  private native void ClearLookup_34();
  public void ClearLookup()
    { ClearLookup_34(); }

  public vtkStringArray() { super(); }

  public vtkStringArray(long id) { super(id); }
  public native long   VTKInit();

}
